@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 # ABSTRACT: This module wraps the www.judobase.org website API.
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use Moo;
 require HTTP::Request;
@@ -11,6 +11,7 @@ require LWP::UserAgent;
 
 use Webservice::Judobase::Competitor;
 use Webservice::Judobase::Contests;
+use Webservice::Judobase::Country;
 use Webservice::Judobase::General;
 
 use namespace::clean;
@@ -39,6 +40,16 @@ has 'contests' => (
     },
 );
 
+has 'country' => (
+    is      => 'ro',
+    default => sub {
+        return Webservice::Judobase::Country->new(
+            ua  => $ua,
+            url => $url,
+        );
+    },
+);
+
 has 'general' => (
     is      => 'ro',
     default => sub {
